```
 ______   __  __    ______    __   __    ______    __     __
/\  == \ /\ \_\ \  /\  ___\  /\ "-.\ \  /\  __ \  /\ \  _ \ \
\ \  _-/ \ \____ \ \ \___  \ \ \ \-.  \ \ \ \/\ \ \ \ \/ ".\ \
 \ \_\    \/\_____\ \/\_____\ \ \_\\"\_\ \ \_____\ \ \__/".~\_\
  \/_/     \/_____/  \/_____/  \/_/ \/_/  \/_____/  \/_/   \/_/
		- Python library for ServiceNow
```

[![image](https://travis-ci.org/rbw/pysnow.svg?branch=master)](https://travis-ci.org/rbw/pysnow)
[![image](https://coveralls.io/repos/github/rbw0/pysnow/badge.svg?branch=master)](https://coveralls.io/github/rbw0/pysnow?branch=master)
[![image](https://badge.fury.io/py/pysnow.svg)](https://pypi.python.org/pypi/pysnow)
[![image](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![image](https://pepy.tech/badge/pysnow/month)](https://pepy.tech/project/pysnow)


Documentation
---

The documentation is available at [https://pysnow.readthedocs.io](https://pysnow.readthedocs.io)


Development status
---

The development status of pysnow is stable; maintenence will be performed, but no new features added.

New features goes into [rbw/aiosnow](https://github.com/rbw/aiosnow): a modern, asynchronous library for interacting with ServiceNow.

Author
---

Robert Wikman \<rbw@vault13.org\>

Credits
---

Thank you [@contributors](https://github.com/rbw/pysnow/graphs/contributors), and [Jetbrains](http://www.jetbrains.com) for IDE licenses.

